# Extended version of QPytorch
#### Author: minhhn2910@github, himeshi@github
## Migration and change of package name

   We have developed multiple new funcionalities and have published the updated version under the new name: qtoch-plus. 
   
   The new version supports arbitrary number of bit for posit (instead of only 16,8,6,4 bitwidth are supported in this version). We also support crafting customized number format with no restriction on the number of bit and the generating rules. More details on our github and in the new pip page:  
   
   [https://pypi.org/project/qtorch-posit](https://pypi.org/project/qtorch-plus)



#### This is developed based on the original QPyTorch package. The below is the original README file and acknowlegement 
## Original Qpytorch:
[![Downloads](https://pepy.tech/badge/qtorch)](https://pepy.tech/project/qtorch) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Original QPyTorch team
* [Tianyi Zhang](https://scholar.google.com/citations?user=OI0HSa0AAAAJ&hl=en)
* Zhiqiu Lin
* [Guandao Yang](http://www.guandaoyang.com/)
* [Christopher De Sa](http://www.cs.cornell.edu/~cdesa/)
